#!/bin/sh -e

# called by uscan with '--upstream-version' <version> <file>
DIR=mei-$2
TAR=../libmei_$2.orig.tar.bz2

# clean up the upstream tarball
unzip $3
tar -c -j -f $TAR $DIR
rm -rf $DIR $3

# move to directory 'tarballs'
if [ -r .svn/deb-layout ]; then
    . .svn/deb-layout
    mv $TAR $origDir
    echo "moved $TAR to $origDir"
fi

exit 0
